From d4ea5a913bcd5027251b611f42132e35b3637a08 Mon Sep 17 00:00:00 2001
From: Stanislav Brabec <sbrabec@suse.com>
Date: Fri, 24 Jul 2015 21:05:32 +0200
Subject: [PATCH 06/12] Add checks for external instances of libraries

To make multi-stage build possible, add checks for external instances of
libraries whenever ext_lib* is set. To be on a safe side, external
libraries must have exactly the same version as the util-linux.

Signed-off-by: Stanislav Brabec <sbrabec@suse.com>
---
 configure.ac | 27 +++++++++++++++++++++++++++
 1 file changed, 27 insertions(+)

diff --git a/configure.ac b/configure.ac
index e704b6e..48191b3 100644
--- a/configure.ac
+++ b/configure.ac
@@ -1995,6 +1995,33 @@ AS_IF([test "x$ADJTIME_PATH" = x], [ADJTIME_PATH="/etc/adjtime"])
 AC_DEFINE_UNQUOTED([CONFIG_ADJTIME_PATH], "$ADJTIME_PATH", [Path to hwclock adjtime file])
 
 
+AS_IF([test "x$ext_libblkid" = xyes], [
+  PKG_CHECK_MODULES([LIBBLKID], [blkid = $LIBBLKID_VERSION], [], [
+    AC_MSG_ERROR([requested external libblkid not found])
+  ])
+])
+AS_IF([test "x$ext_libfdisk" = xyes], [
+  PKG_CHECK_MODULES([LIBFDISK], [fdisk = $LIBFDISK_VERSION], [], [
+    AC_MSG_ERROR([requested external libfdisk not found])
+  ])
+])
+AS_IF([test "x$ext_libmount" = xyes], [
+  PKG_CHECK_MODULES([LIBMOUNT], [mount = $LIBMOUNT_VERSION], [], [
+    AC_MSG_ERROR([requested external libblkid not found])
+  ])
+])
+AS_IF([test "x$ext_libsmartcols" = xyes], [
+  PKG_CHECK_MODULES([LIBSMARTCOLS], [smartcols = $LIBSMARTCOLS_VERSION], [], [
+    AC_MSG_ERROR([requested external libsmartcols not found])
+  ])
+])
+AS_IF([test "x$ext_libuuid" = xyes], [
+  PKG_CHECK_MODULES([LIBUUID], [uuid = $LIBUUID_VERSION], [], [
+    AC_MSG_ERROR([requested external libuuid not found])
+  ])
+])
+
+
 LIBS=""
 
 
-- 
2.4.5

